API Reference
=============

This page provides an auto-generated summary of pop-tool's API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.


.. currentmodule:: pop_tools

Grid
~~~~

.. autosummary::
   get_grid

Equation of State
~~~~~~~~~~~~~~~~~

.. autosummary::
   eos
   compute_pressure

Region masks
~~~~~~~~~~~~

.. autosummary::
   region_mask_3d
   list_region_masks


Utilities
~~~~~~~~~

.. autosummary::
   lateral_fill


xgcm utilities
~~~~~~~~~~~~~~

.. autosummary::
   to_xgcm_grid_dataset

.. currentmodule:: pop_tools

.. autofunction:: get_grid

.. autofunction:: eos

.. autofunction:: compute_pressure

.. autofunction:: region_mask_3d

.. autofunction:: list_region_masks

.. autofunction:: lateral_fill

.. autofunction:: to_xgcm_grid_dataset
